Once you run PGP_Reconstruction for this first time, this folder will receive a local copy of files and databases downloaded from a [external server](https://files.ufz.de/~umb-pgp_reconstruction-01/).